/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model.uinfo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.dive4elements.river.model.River;

/**
 * Hibernate binding for the DB table vegetation
 *
 * @author Matthias Schäfer
 *
 */

@Entity
@Table(name = "vegetation")
public class Vegetation implements Serializable {

    /***** FIELDS *****/

    private static final long serialVersionUID = -2264657956270172835L;

    private Integer id;

    private River river;

    private String filename;

    private String name;

    private String notes;

    private List<VegetationZone> values;


    /***** CONSTRUCTORS *****/

    public Vegetation() {
    }


    public Vegetation(final River river, final String filename, final String name, final String notes) {
        this.river = river;
        this.filename = filename;
        this.name = name;
        this.notes = notes;
        this.values = new ArrayList<>();
    }


    /***** METHODS *****/

    @Id
    @SequenceGenerator(name = "SEQUENCE_VEGETATION_ID_SEQ", sequenceName = "VEGETATION_ID_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQUENCE_VEGETATION_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return this.river;
    }

    public void setRiver(final River river) {
        this.river = river;
    }

    @Column(name = "filename")
    public String getFilename() {
        return this.filename;
    }

    public void setFilename(final String filename) {
        this.filename = filename;
    }

    @Column(name = "name")
    public String getName() {
        return this.name;
    }

    public void setName(final String name) {
        this.name = name;
    }

    @Column(name = "notes")
    public String getNotes() {
        return this.notes;
    }

    public void setNotes(final String notes) {
        this.notes = notes;
    }

    @OneToMany
    @JoinColumn(name = "vegetation_id")
    public List<VegetationZone> getValues() {
        return this.values;
    }

    public void setValues(final List<VegetationZone> values) {
        this.values = values;
    }

    public void addValue(final VegetationZone value) {
        this.values.add(value);
    }
}